# -*- coding:utf-8 -*-
'''
@Author：Robin.lau
@Email: 329080237@qq.com
@Wechat: 15618110227
@File: urls.py
@Date: 2021/2/27 13:45
@Description: Api地址配置文件
'''
from django.urls import path
from web.git import repository, kernel, users, issues

urlpatterns = [

    # repos APIs 仓库/代码项目查询
    path('repos/create/', repository.create),   # 创建仓库
    path('repos/search/', repository.search),   # 查询公开项目列表
    path('repos/<str:owner>/<str:repo>/', repository.getRepo), # 查询仓库详情信息
    path('repos/<str:owner>/<str:repo>/branches/', repository.getBranches),  # 获取项目分支列表
    path('repos/<str:owner>/<str:repo>/commits', repository.getCommits),  # 获取当前分支提交数
    path('repos/<str:owner>/<str:repo>/contents/<str:filepath>', repository.readme),    # 读取README.md
    path('repos/<str:owner>/<str:repo>/contents/', repository.getRepoTree), # 获取分支目录树
    # path('repos/<str:owner>/<str:repo>/downloadZIP/', repository.downloadZIP),  # 下载分支
    path('repos/<str:owner>/<str:repo>/lastCommit/', repository.lastCommit),  # 获取分支最后一次提交者信息

    # Issues APIs /repos/Write-Bug/write-bug/issues
    path('repos/<str:owner>/<str:repo>/issues/', issues.getIssues),  # 查询issues列表
    path('repos/<str:owner>/<str:repo>/issues/<int:id>', issues.issueDetail),  # 查询issues列表
    path('repos/<str:owner>/<str:repo>/issues/create/', issues.createIssue),  # 创建issue
    path('repos/<str:owner>/<str:repo>/issues/update/<int:id>', issues.updateIssue),  # 更新issue
    path('repos/<str:owner>/<str:repo>/issuesClosedTotal/', issues.getIssuesClosedTotal),  # 查询issues已关闭数
    path('repos/<str:owner>/<str:repo>/getRepoLabels/', issues.getRepoLabels),  # 查询issues中标签列表
    path('repos/<str:owner>/<str:repo>/getCollaborators/', issues.getCollaborators),  # 查询项目协作者列表
    path('repos/<str:owner>/<str:repo>/createRepoLabel/', issues.createRepoLabel),  # 创建标签
    path('repos/<str:owner>/<str:repo>/updateRepoLabel/<int:id>', issues.updateRepoLabel),  # 修改标签
    path('repos/<str:owner>/<str:repo>/delRepoLabel/<int:id>', issues.delRepoLabel),  # 删除标签

    # 项目评估
    path('kernel/code_analysis_result_call_back/', kernel.code_analysis_result_call_back),  # 生成项目评估报告 回调
    path('code_analysis_test/', kernel.code_analysis_test),  # 发送评估请求
    path('kernel/reportView/', kernel.reportView)   # 评估报告总览


    # users APIs
]
